pub fn pmsafe(
ra1: f64,
dec1: f64,
pmr1: f64,
pmd1: f64,
px1: f64,
rv1: f64,
ep1a: f64,
ep1b: f64,
ep2a: f64,
ep2b: f64,
) -> Result<([f64; 6], i32), i32>Expand description
Star proper motion: update star catalog data for space motion, with special handling to handle the zero parallax case.
This function is part of the International Astronomical Union’s SOFA (Standards of Fundamental Astronomy) software collection.
Status: support function.
Given: ra1 double right ascension (radians), before dec1 double declination (radians), before pmr1 double RA proper motion (radians/year), before pmd1 double Dec proper motion (radians/year), before px1 double parallax (arcseconds), before rv1 double radial velocity (km/s, +ve = receding), before ep1a double “before” epoch, part A (Note 1) ep1b double “before” epoch, part B (Note 1) ep2a double “after” epoch, part A (Note 1) ep2b double “after” epoch, part B (Note 1)
Returned: (ra2, dec2, pmr2, pmd2, px2, rv2)
Returned (function value): int status: -1 = system error (should not occur) 0 = no warnings or errors 1 = distance overridden (Note 6) 2 = excessive velocity (Note 7) 4 = solution didn’t converge (Note 8) else = binary logical OR of the above warnings
Notes:
-
The starting and ending TDB dates ep1a+ep1b and ep2a+ep2b are Julian Dates, apportioned in any convenient way between the two parts (A and B). For example, JD(TDB)=2450123.7 could be expressed in any of these ways, among others:
epNa epNb 2450123.7 0.0 (JD method) 2451545.0 -1421.3 (J2000 method) 2400000.5 50123.2 (MJD method) 2450123.5 0.2 (date & time method)The JD method is the most natural and convenient to use in cases where the loss of several decimal digits of resolution is acceptable. The J2000 method is best matched to the way the argument is handled internally and will deliver the optimum resolution. The MJD method and the date & time methods are both good compromises between resolution and convenience.
-
In accordance with normal star-catalog conventions, the object’s right ascension and declination are freed from the effects of secular aberration. The frame, which is aligned to the catalog equator and equinox, is Lorentzian and centered on the SSB.
The proper motions are the rate of change of the right ascension and declination at the catalog epoch and are in radians per TDB Julian year.
The parallax and radial velocity are in the same frame.
-
Care is needed with units. The star coordinates are in radians and the proper motions in radians per Julian year, but the parallax is in arcseconds.
-
The RA proper motion is in terms of coordinate angle, not true angle. If the catalog uses arcseconds for both RA and Dec proper motions, the RA proper motion will need to be divided by cos(Dec) before use.
-
Straight-line motion at constant speed, in the inertial frame, is assumed.
-
An extremely small (or zero or negative) parallax is overridden to ensure that the object is at a finite but very large distance, but not so large that the proper motion is equivalent to a large but safe speed (about 0.1c using the chosen constant). A warning status of 1 is added to the status if this action has been taken.
-
If the space velocity is a significant fraction of c (see the constant VMAX in the function iauStarpv), it is arbitrarily set to zero. When this action occurs, 2 is added to the status.
-
The relativistic adjustment carried out in the iauStarpv function involves an iterative calculation. If the process fails to converge within a set number of iterations, 4 is added to the status.
Called: iauSeps angle between two points iauStarpm update star catalog data for space motion