Module pnp

Module pnp 

Precession, nutation, polar motion

Functions

bi00
Frame bias components, IAU 2000
bp00
Frame bias and precession matrices, IAU 2000.
bp06
Frame bias and precession, IAU 2006.
bpn2xy
Extract CIP X,Y coordinates from NPB matrix
c2i00a
Form the celestial-to-intermediate matrix for a given date using the IAU 2000A precession-nutation model.
c2i00b
Form the celestial-to-intermediate matrix for a given date using the IAU 2000B precession-nutation model.
c2i06a
Form the celestial-to-intermediate matrix for a given date using the IAU 2006 precession and IAU 2000A nutation models.
c2ibpn
Form the celestial-to-intermediate matrix for a given date given the bias-precession-nutation matrix. IAU 2000.
c2ixy
Form the celestial to intermediate-frame-of-date matrix for a given date when the CIP X,Y coordinates are known. IAU 2000.
c2ixys
Celestial−to−intermediate matrix, given X,Y, IAU 2000
c2t00a
Form the celestial to terrestrial matrix given the date, the UT1 and the polar motion, using the IAU 2000A precession-nutation model.
c2t00b
Form the celestial to terrestrial matrix given the date, the UT1 and the polar motion, using the IAU 2000B precession-nutation model.
c2t06a
Form the celestial to terrestrial matrix given the date, the UT1 and the polar motion, using the IAU 2006/2000A precession-nutation model.
c2tcio
Assemble the celestial to terrestrial matrix from CIO-based components (the celestial-to-intermediate matrix, the Earth Rotation Angle and the polar motion matrix).
c2teqx
Assemble the celestial to terrestrial matrix from equinox-based components (the celestial-to-true matrix, the Greenwich Apparent Sidereal Time and the polar motion matrix).
c2tpe
Form the celestial to terrestrial matrix given the date, the UT1, the nutation and the polar motion. IAU 2000.
c2txy
Form the celestial to terrestrial matrix given the date, the UT1, the CIP coordinates and the polar motion. IAU 2000.
eo06a
Equation of the origins, IAU 2006 precession and IAU 2000A nutation.
eors
Equation of the origins, given the classical NPB matrix and the quantity s.
fw2m
Form rotation matrix given the Fukushima-Williams angles.
fw2xy
CIP X,Y given Fukushima-Williams bias-precession-nutation angles.
ltp
Long-term precession matrix.
ltpb
Long-term precession matrix, including ICRS frame bias.
ltpecl
Long-term precession of the ecliptic.
ltpequ
Long-term precession of the equator.
num00a
Form the matrix of nutation for a given date, IAU 2000A model.
num00b
Form the matrix of nutation for a given date, IAU 2000B model.
num06a
Form the matrix of nutation for a given date, IAU 2006/2000A model.
numat
Form the matrix of nutation.
nut00a
Nutation, IAU 2000A
nut00b
nutation, IAU 2000B
nut06a
IAU 2000A nutation with adjustments to match the IAU 2006 precession.
nut80
Nutation, IAU 1980 model.
nutm80
Form the matrix of nutation for a given date, IAU 1980 model.
obl06
Mean obliquity of the ecliptic, IAU 2006 precession model.
obl80
Mean obliquity of the ecliptic, IAU 1980 model.
p06e
Precession angles, IAU 2006, equinox based.
pb06
This function forms three Euler angles which implement general precession from epoch J2000.0, using the IAU 2006 model. Frame bias (the offset between ICRS and mean J2000.0) is included.
pfw06
Precession angles, IAU 2006 (Fukushima-Williams 4-angle formulation).
pmat00
Precession matrix (including frame bias) from GCRS to a specified date, IAU 2000 model.
pmat06
Precession matrix (including frame bias) from GCRS to a specified date, IAU 2006 model.
pmat76
Precession matrix from J2000.0 to a specified date, IAU 1976 model.
pn00
Bias/precession/nutation results, IAU 2000
pn00a
Bias/precession/nutation, IAU 2000A
pn00b
Bias/precession/nutation, IAU 2000B
pn06
Precession-nutation, IAU 2006 model: a multi-purpose function, supporting classical (equinox-based) use directly and CIO-based use indirectly.
pn06a
Precession-nutation, IAU 2006/2000A models: a multi-purpose function, supporting classical (equinox-based) use directly and CIO-based use indirectly.
pnm00a
Classical NPB matrix, IAU 2000A
pnm00b
Form the matrix of precession-nutation for a given date (including frame bias), equinox-based, IAU 2000B model.
pnm06a
Classical NPB matrix, IAU 2006/2000A
pnm80
Form the matrix of precession/nutation for a given date, IAU 1976 precession model, IAU 1980 nutation model.
pom00
Form the matrix of polar motion for a given date, IAU 2000.
pr00
Precession-rate part of the IAU 2000 precession-nutation models (part of MHB2000).
prec76
IAU 1976 precession model.
s00
The CIO locator s, positioning the Celestial Intermediate Origin on the equator of the Celestial Intermediate Pole, given the CIP’s X,Y coordinates. Compatible with IAU 2000A precession-nutation.
s00a
The CIO locator s, positioning the Celestial Intermediate Origin on the equator of the Celestial Intermediate Pole, using the IAU 2000A precession-nutation model.
s00b
The CIO locator s, positioning the Celestial Intermediate Origin on the equator of the Celestial Intermediate Pole, using the IAU 2000B precession-nutation model.
s06
The CIO locator s, positioning the Celestial Intermediate Origin on the equator of the Celestial Intermediate Pole, given the CIP’s X,Y coordinates. Compatible with IAU 2006/2000A precession-nutation.
s06a
The CIO locator s, positioning the Celestial Intermediate Origin on the equator of the Celestial Intermediate Pole, using the IAU 2006 precession and IAU 2000A nutation models.
sp00
The TIO locator s’, positioning the Terrestrial Intermediate Origin on the equator of the Celestial Intermediate Pole.
xy06
X,Y coordinates of celestial intermediate pole from series based on IAU 2006 precession and IAU 2000A nutation.
xys00a
For a given TT date, compute the X,Y coordinates of the Celestial Intermediate Pole and the CIO locator s, using the IAU 2000A precession-nutation model.
xys00b
For a given TT date, compute the X,Y coordinates of the Celestial Intermediate Pole and the CIO locator s, using the IAU 2000B precession-nutation model.
xys06a
For a given TT date, compute the X,Y coordinates of the Celestial Intermediate Pole and the CIO locator s, using the IAU 2006 precession and IAU 2000A nutation models.