p06e

Function p06e 

pub fn p06e(
    date1: f64,
    date2: f64,
) -> (f64, f64, f64, f64, f64, f64, f64, f64, f64, f64, f64, f64, f64, f64, f64, f64)
Precession angles, IAU 2006, equinox based.

This function is part of the International Astronomical Union’s SOFA (Standards of Fundamental Astronomy) software collection.

Status: canonical models.

Given: date1,date2 f64 TT as a 2-part Julian Date (Note 1)

Returned (see Note 2): eps0 f64 epsilon_0 psia f64 psi_A oma f64 omega_A bpa f64 P_A bqa f64 Q_A pia f64 pi_A bpia f64 Pi_A epsa f64 obliquity epsilon_A chia f64 chi_A za f64 z_A zetaa f64 zeta_A thetaa f64 theta_A pa f64 p_A gam f64 F-W angle gamma_J2000 phi f64 F-W angle phi_J2000 psi f64 F-W angle psi_J2000

Notes:

  1. The TT date date1+date2 is a Julian Date, apportioned in any convenient way between the two arguments. For example, JD(TT)=2450123.7 could be expressed in any of these ways, among others:
          date1          date2

       2450123.7           0.0       (JD method)
       2451545.0       -1421.3       (J2000 method)
       2400000.5       50123.2       (MJD method)
       2450123.5           0.2       (date & time method)

The JD method is the most natural and convenient to use in cases where the loss of several decimal digits of resolution is acceptable. The J2000 method is best matched to the way the argument is handled internally and will deliver the optimum resolution. The MJD method and the date & time methods are both good compromises between resolution and convenience.

  1. This function returns the set of equinox based angles for the Capitaine et al. “P03” precession theory, adopted by the IAU in 2006. The angles are set out in Table 1 of Hilton et al. (2006):

    eps0 epsilon_0 obliquity at J2000.0 psia psi_A luni-solar precession oma omega_A inclination of equator wrt J2000.0 ecliptic bpa P_A ecliptic pole x, J2000.0 ecliptic triad bqa Q_A ecliptic pole -y, J2000.0 ecliptic triad pia pi_A angle between moving and J2000.0 ecliptics bpia Pi_A longitude of ascending node of the ecliptic epsa epsilon_A obliquity of the ecliptic chia chi_A planetary precession za z_A equatorial precession: -3rd 323 Euler angle zetaa zeta_A equatorial precession: -1st 323 Euler angle thetaa theta_A equatorial precession: 2nd 323 Euler angle pa p_A general precession (n.b. see below) gam gamma_J2000 J2000.0 RA difference of ecliptic poles phi phi_J2000 J2000.0 codeclination of ecliptic pole psi psi_J2000 longitude difference of equator poles, J2000.0

    The returned values are all radians.

    Note that the t^5 coefficient in the series for p_A from Capitaine et al. (2003) is incorrectly signed in Hilton et al. (2006).

  2. Hilton et al. (2006) Table 1 also contains angles that depend on models distinct from the P03 precession theory itself, namely the IAU 2000A frame bias and nutation. The quoted polynomials are used in other SOFA functions:

    . iauXy06 contains the polynomial parts of the X and Y series.

    . iauS06 contains the polynomial part of the s+XY/2 series.

    . iauPfw06 implements the series for the Fukushima-Williams angles that are with respect to the GCRS pole (i.e. the variants that include frame bias).

  3. The IAU resolution stipulated that the choice of parameterization was left to the user, and so an IAU compliant precession implementation can be constructed using various combinations of the angles returned by the present function.

  4. The parameterization used by SOFA is the version of the Fukushima- Williams angles that refers directly to the GCRS pole. These angles may be calculated by calling the function iauPfw06. SOFA also supports the direct computation of the CIP GCRS X,Y by series, available by calling iauXy06.

  5. The agreement between the different parameterizations is at the 1 microarcsecond level in the present era.

  6. When constructing a precession formulation that refers to the GCRS pole rather than the dynamical pole, it may (depending on the choice of angles) be necessary to introduce the frame bias explicitly.

References:

Capitaine, N., Wallace, P.T. & Chapront, J., 2003, Astron.Astrophys., 412, 567

Hilton, J. et al., 2006, Celest.Mech.Dyn.Astron. 94, 351