Module projection

Module projection 

Gnomonic projection

Functions

tpors
In the tangent plane projection, given the rectangular coordinates of a star and its spherical coordinates, determine the spherical coordinates of the tangent point.
tporv
In the tangent plane projection, given the rectangular coordinates of a star and its direction cosines, determine the direction cosines of the tangent point.
tpsts
In the tangent plane projection, given the star’s rectangular coordinates and the spherical coordinates of the tangent point, solve for the spherical coordinates of the star.
tpstv
In the tangent plane projection, given the star’s rectangular coordinates and the direction cosines of the tangent point, solve for the direction cosines of the star.
tpxes
In the tangent plane projection, given celestial spherical coordinates for a star and the tangent point, solve for the star’s rectangular coordinates in the tangent plane.
tpxev
In the tangent plane projection, given celestial direction cosines for a star and the tangent point, solve for the star’s rectangular coordinates in the tangent plane.