pub fn fk5hz(r5: f64, d5: f64, date1: f64, date2: f64) -> (f64, f64)Expand description
Transform an FK5 (J2000.0) star position into the system of the Hipparcos catalog, assuming zero Hipparcos proper motion.
Status: support function.
Given: r5 f64 FK5 RA (radians), equinox J2000.0, at date d5 f64 FK5 Dec (radians), equinox J2000.0, at date date1,date2 f64 TDB date (Notes 1,2)
Returned: rh f64 Hipparcos RA (radians) dh f64 Hipparcos Dec (radians)
Notes:
-
This function converts a star position from the FK5 system to the Hipparcos system, in such a way that the Hipparcos proper motion is zero. Because such a star has, in general, a non-zero proper motion in the FK5 system, the function requires the date at which the position in the FK5 system was determined.
-
The TT date date1+date2 is a Julian Date, apportioned in any convenient way between the two arguments. For example, JD(TT)=2450123.7 could be expressed in any of these ways, among others:
date1 date2 2450123.7 0.0 (JD method) 2451545.0 -1421.3 (J2000 method) 2400000.5 50123.2 (MJD method) 2450123.5 0.2 (date & time method)The JD method is the most natural and convenient to use in cases where the loss of several decimal digits of resolution is acceptable. The J2000 method is best matched to the way the argument is handled internally and will deliver the optimum resolution. The MJD method and the date & time methods are both good compromises between resolution and convenience.
-
The FK5 to Hipparcos transformation is modeled as a pure rotation and spin; zonal errors in the FK5 catalog are not taken into account.
-
The position returned by this function is in the Hipparcos reference system but at date date1+date2.
-
See also fk52h, h2fk5, hfk5z.
Called: s2c spherical coordinates to unit vector fk5hip FK5 to Hipparcos rotation and spin sxp multiply p-vector by scalar rv2m r-vector to r-matrix trxp product of transpose of r-matrix and p-vector rxp product of r-matrix and p-vector c2s p-vector to spherical anp normalize angle into range 0 to 2pi
Reference: F.Mignard & M.Froeschle, 2000, Astron.Astrophys. 354, 732-739.