Module ts

Module ts 

Time scales

Functions

d2dtf
Format for output a 2-part Julian Date (or in the case of UTC a quasi-JD form that includes special provision for leap seconds).
dat
For a given UTC date, calculate Delta(AT) = TAI-UTC.
dtdb
TDB-TT difference
dtf2d
Encode date and time fields into 2-part Julian Date (or in the case of UTC a quasi-JD form that includes special provision for leap seconds).
taitt
taiut1
taiutc
Time scale transformation: International Atomic Time, TAI, to Coordinated Universal Time, UTC.
tcbtdb
Time scale transformation: Barycentric Coordinate Time, TCB, to Barycentric Dynamical Time, TDB.
tcgtt
Time scale transformation: Geocentric Coordinate Time, TCG, to Terrestrial Time, TT.
tdbtcb
Time scale transformation: Barycentric Dynamical Time, TDB, to Barycentric Coordinate Time, TCB.
tdbtt
Time scale transformation: Barycentric Dynamical Time, TDB, to Terrestrial Time, TT.
tttai
Time scale transformation: Terrestrial Time, TT, to International Atomic Time, TAI.
tttcg
Time scale transformation: Terrestrial Time, TT, to Geocentric Coordinate Time, TCG.
tttdb
Time scale transformation: Terrestrial Time, TT, to Barycentric Dynamical Time, TDB.
ttut1
Time scale transformation: Terrestrial Time, TT, to Universal Time, UT1.
ut1tai
Time scale transformation: Universal Time, UT1, to International Atomic Time, TAI.
ut1tt
Time scale transformation: Universal Time, UT1, to Terrestrial Time, TT.
ut1utc
Time scale transformation: Universal Time, UT1, to Coordinated Universal Time, UTC.
utctai

utcut1
Time scale transformation: Coordinated Universal Time, UTC, to Universal Time, UT1.