pub fn pmp(a: &[f64; 3], b: &[f64; 3]) -> [f64; 3]Expand description
P-vector subtraction.
This function is part of the International Astronomical Union’s SOFA (Standards of Fundamental Astronomy) software collection.
Status: vector/matrix support function.
Given:
a double[3] first p-vector
b double[3] second p-vectorReturned:
amb double[3] a - bNote: It is permissible to re-use the same array for any of the arguments.